package com.om.config;

import org.apache.catalina.connector.Connector;
import org.apache.coyote.http11.Http11NioProtocol;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.web.embedded.tomcat.TomcatServletWebServerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class AndroidSslConfiguration {

    @Value("${android.ssl.key-store}")
    private String keyStore;

    @Value("${android.ssl.key-store-password}")
    private String keyStorePassword;

    @Value("${android.ssl.key-store-type}")
    private String keyStoreType;

    @Value("${android.ssl.key-alias}")
    private String keyAlias;

    @Value("${android.server.port}")
    private int androidPort;

    @Bean
    public TomcatServletWebServerFactory servletContainer() {
        TomcatServletWebServerFactory tomcat = new TomcatServletWebServerFactory();
        tomcat.addAdditionalTomcatConnectors(createSslConnector());
        return tomcat;
    }

    private Connector createSslConnector() {
        Connector connector = new Connector(Http11NioProtocol.class.getName());
        Http11NioProtocol protocol = (Http11NioProtocol) connector.getProtocolHandler();
        try {
            connector.setScheme("https");
            connector.setPort(androidPort);
            connector.setSecure(true);
            protocol.setSSLEnabled(true);
            protocol.setKeystoreFile(keyStore);
            protocol.setKeystorePass(keyStorePassword);
            protocol.setKeystoreType(keyStoreType);
            protocol.setKeyAlias(keyAlias);
            // 如果你没有 truststore.p12，可以忽略或配置成一样的
            // protocol.setTruststoreFile(keyStore);
            // protocol.setTruststorePass(keyStorePassword);
            // protocol.setTruststoreType(keyStoreType);
            protocol.setClientAuth("required");  // 确保正确配置为 "need" 而不是 "required"
            protocol.setSslProtocol("TLS");
        } catch (Exception ex) {
            throw new IllegalStateException("Failed to create SSL connector", ex);
        }
        return connector;
    }
}
